pytilities.test.overloading.overloaded.A

Package pytilities :: Package test :: Package overloading :: Module overloaded :: Class A |
[hide private]
[frames] | no frames]

# Class A

source code

    object --+
             |
            A

Some class to test with

Instance Methods | [hide private]
__init_xy(self, x, y) | source code
__init_storage(self, storage) | source code
say_ni(*args, **kwargs) docstring is docstring | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### say_ni(*args, **kwargs) | source code
docstring is docstring Decorators: `@overloaded((Overload(__init_xy, Param("x", NumberType, default= 0), Param("y", NumberType, default= 0)), Overload(__init_storage, Param("storage"))))`